==> ml-natural-language-6.3.1.tgz: package/README.md <==
<p align="center">
  <a href="https://invertase.io/oss/react-native-firebase">
    <img width="160px" src="https://i.imgur.com/JIyBtKW.png"><br/>
  </a>
  <h2 align="center">React Native Firebase - ML Kit Natural Language</h2>
</p>

<p align="center">
  <a href="https://api.rnfirebase.io/coverage/ml-natural-language/detail"><img src="https://api.rnfirebase.io/coverage/ml-natural-language/badge?style=flat-square" alt="Coverage"></a>
  <a href="https://www.npmjs.com/package/@react-native-firebase/ml-natural-language"><img src="https://img.shields.io/npm/dm/@react-native-firebase/ml-natural-language.svg?style=flat-square" alt="NPM downloads"></a>
  <a href="https://www.npmjs.com/package/@react-native-firebase/ml-natural-language"><img src="https://img.shields.io/npm/v/@react-native-firebase/ml-natural-language.svg?style=flat-square" alt="NPM version"></a>
  <a href="/LICENSE"><img src="https://img.shields.io/npm/l/react-native-firebase.svg?style=flat-square" alt="License"></a>
  <a href="https://lerna.js.org/"><img src="https://img.shields.io/badge/maintained%20with-lerna-cc00ff.svg?style=flat-square" alt="Maintained with Lerna"></a>
</p>

<p align="center">
  <a href="https://invertase.link/discord"><img src="https://img.shields.io/discord/295953187817521152.svg?style=flat-square&colorA=7289da&label=Chat%20on%20Discord" alt="Chat on Discord"></a>
  <a href="https://twitter.com/rnfirebase"><img src="https://img.shields.io/twitter/follow/rnfirebase.svg?style=flat-square&colorA=1da1f2&colorB=&label=Follow%20on%20Twitter" alt="Follow on Twitter"></a>
  <a href="https://www.facebook.com/groups/rnfirebase"><img src="https://img.shields.io/badge/Follow%20on%20Facebook-4172B8?logo=facebook&style=flat-square&logoColor=fff" alt="Follow on Facebook"></a>
</p>

---

Bring powerful machine learning features to your mobile app whether you're new or experienced in ML. Get started easily by using ready-to-use APIs from Firebase for common mobile use cases, or import your own custom models which can be hosted and served to your apps by Firebase. ML Kit APIs can run on-device or in the cloud, depending on the functionality, and some give you both choices.

**This module supports the following APIs:**

| API                                 | Supported |
|-------------------------------------|-----------|
| [Language Identification](https://firebase.google.com/docs/ml-kit/identify-languages)             | ✅        |
| [Smart Reply](https://firebase.google.com/docs/ml-kit/generate-smart-replies)                         | ✅        |
| [Translate](https://firebase.google.com/docs/ml-kit/translation)                           | ❌        |


[> Learn More](https://firebase.google.com/products/ml-kit/)

## Installation

Requires `@react-native-firebase/app` to be installed.

```bash
yarn add @react-native-firebase/ml-natural-language
```

## Documentation

- [Quick Start](https://invertase.io/oss/react-native-firebase/v6/ml-natural-language)
- [Guides](https://invertase.io/oss/react-native-firebase/guides?tags=ml-language)
- [Reference](https://invertase.io/oss/react-native-firebase/v6/ml-natural-language/reference)

## License

- See [LICENSE](/LICENSE)

---

<p>
  <img align="left" width="75px" src="https://static.invertase.io/assets/invertase-logo-small.png"> 
  <p align="left">  
    Built and maintained with 💛 by <a href="https://invertase.io">Invertase</a>.
  </p>
  <p align="left">  
    <a href="https://invertase.io/hire-us">💼 Hire Us</a> | 
    <a href="https://opencollective.com/react-native-firebase">☕️ Sponsor Us</a> | 
    <a href="https://opencollective.com/jobs">‍💻 Work With Us</a>
  </p>
</p>

---

==> ml-natural-language-7.0.1.tgz: package/README.md <==
<p align="center">
  <a href="https://rnfirebase.io">
    <img width="160px" src="https://i.imgur.com/JIyBtKW.png"><br/>
  </a>
  <h2 align="center">React Native Firebase - ML Kit Natural Language</h2>
</p>

<p align="center">
  <a href="https://api.rnfirebase.io/coverage/ml-natural-language/detail"><img src="https://api.rnfirebase.io/coverage/ml-natural-language/badge?style=flat-square" alt="Coverage"></a>
  <a href="https://www.npmjs.com/package/@react-native-firebase/ml-natural-language"><img src="https://img.shields.io/npm/dm/@react-native-firebase/ml-natural-language.svg?style=flat-square" alt="NPM downloads"></a>
  <a href="https://www.npmjs.com/package/@react-native-firebase/ml-natural-language"><img src="https://img.shields.io/npm/v/@react-native-firebase/ml-natural-language.svg?style=flat-square" alt="NPM version"></a>
  <a href="/LICENSE"><img src="https://img.shields.io/npm/l/react-native-firebase.svg?style=flat-square" alt="License"></a>
  <a href="https://lerna.js.org/"><img src="https://img.shields.io/badge/maintained%20with-lerna-cc00ff.svg?style=flat-square" alt="Maintained with Lerna"></a>
</p>

<p align="center">
  <a href="https://invertase.link/discord"><img src="https://img.shields.io/discord/295953187817521152.svg?style=flat-square&colorA=7289da&label=Chat%20on%20Discord" alt="Chat on Discord"></a>
  <a href="https://twitter.com/rnfirebase"><img src="https://img.shields.io/twitter/follow/rnfirebase.svg?style=flat-square&colorA=1da1f2&colorB=&label=Follow%20on%20Twitter" alt="Follow on Twitter"></a>
  <a href="https://www.facebook.com/groups/rnfirebase"><img src="https://img.shields.io/badge/Follow%20on%20Facebook-4172B8?logo=facebook&style=flat-square&logoColor=fff" alt="Follow on Facebook"></a>
</p>

---

Bring powerful machine learning features to your mobile app whether you're new or experienced in ML. Get started easily by using ready-to-use APIs from Firebase for common mobile use cases, or import your own custom models which can be hosted and served to your apps by Firebase. ML Kit APIs can run on-device or in the cloud, depending on the functionality, and some give you both choices.

**This module supports the following APIs:**

| API                                 | Supported |
|-------------------------------------|-----------|
| [Language Identification](https://firebase.google.com/docs/ml-kit/identify-languages)             | ✅        |
| [Smart Reply](https://firebase.google.com/docs/ml-kit/generate-smart-replies)                         | ✅        |
| [Translate](https://firebase.google.com/docs/ml-kit/translation)                           | ❌        |


[> Learn More](https://firebase.google.com/products/ml-kit/)

## Installation

Requires `@react-native-firebase/app` to be installed.

```bash
yarn add @react-native-firebase/ml-natural-language
```

## Documentation

- [Quick Start](https://rnfirebase.io/ml-natural-language/usage)
- [Reference](https://rnfirebase.io/reference/ml-natural-language)

## License

- See [LICENSE](/LICENSE)

---

<p>
  <img align="left" width="75px" src="https://static.invertase.io/assets/invertase-logo-small.png">
  <p align="left">
    Built and maintained with 💛 by <a href="https://invertase.io">Invertase</a>.
  </p>
</p>

---
